IncomingSession

Type Alias IncomingSession 

pub type IncomingSession = IncomingSession<HoprSession>;
Wrapper for an incoming HoprSession carrying the SessionId and SessionTarget extracted from the Start protocol during session establishment.

This is the published generic [hopr_api::node::IncomingSession] specialized to the concrete HoprSession byte-stream.

Aliased Type

pub struct IncomingSession {
    pub id: SimplePseudonym,
    pub session: HoprSession,
    pub target: SessionTarget,
}

Fields

id: SimplePseudonym

Identifier of the incoming session.

session: HoprSession

The session byte-stream carrying the forwarded data.

target: SessionTarget

Describes where data received over the session should be forwarded.